'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Класс для работы с токенами.
 */
var TokenHelper = function () {
    function TokenHelper() {
        _classCallCheck(this, TokenHelper);
    }

    _createClass(TokenHelper, [{
        key: 'setToken',

        /**
         * Установка токенов.
         *
         * @param {string} access_token
         * @param {int} expires_in
         * @param token_type
         * @param {string} refresh_token
         */
        value: function setToken(access_token, expires_in) {
            var token_type = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'Bearer';
            var refresh_token = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : undefined;


            var results = [this.setAccessToken(access_token), this.setTokenExpire(expires_in), this.setTokenType(token_type), this.setRefreshToken(refresh_token)];

            var errors = [];

            results.forEach(function (result) {
                if (result instanceof Error) {
                    console.warn(result);
                    return errors.push(result);
                }
            });

            if (errors.length > 0) {
                return errors[0];
            }

            return errors.length > 0 ? errors[0] : true;
        }
    }, {
        key: 'setAccessToken',
        value: function setAccessToken(access_token) {
            if (typeof access_token !== 'string' || access_token.length < 1) {
                return new Error('Переданное значение должно быть строкой и не быть пустой!');
            } else {
                localStorage.setItem('access_token', access_token);
                return true;
            }
        }
    }, {
        key: 'setTokenType',
        value: function setTokenType(token_type) {
            if (typeof token_type !== 'string' || token_type.length < 1) {
                return new Error('Переданное значение должно быть строкой и не быть пустой!');
            } else {
                localStorage.setItem('token_type', token_type);
                return true;
            }
        }
    }, {
        key: 'setTokenExpire',
        value: function setTokenExpire(expire_time) {
            if (typeof expire_time !== 'number') {
                return new Error('Переданное значение должно быть числом!');
            } else {
                localStorage.setItem('expires_in', expire_time + +new Date());
                return true;
            }
        }
    }, {
        key: 'setRefreshToken',
        value: function setRefreshToken(refresh_token) {
            if (typeof refresh_token !== 'undefined' && (typeof refresh_token !== 'string' || refresh_token.length < 1)) {
                return new Error('Переданное значение может быть не обязательным или должно быть строкой и не быть пустой!');
            } else {
                localStorage.setItem('refresh_token', refresh_token);
                return true;
            }
        }

        /**
         * Проверить авторизованность (наличие установленного токена и время его жизни).
         */

    }, {
        key: 'isAuthenticated',
        value: function isAuthenticated() {
            return !this.tokenWasExpired() && !!this.getToken();
        }

        /**
         * Получить токен доступа.
         */

    }, {
        key: 'getToken',
        value: function getToken() {
            return localStorage.getItem('access_token');
        }

        /**
         * Проверить, истекло ли время жизни токена.
         */

    }, {
        key: 'tokenWasExpired',
        value: function tokenWasExpired() {
            var expires_in = localStorage.getItem('expires_in');

            return !expires_in ? false : new Date() >= expires_in;
        }

        /**
         * Удалить токены из хранилища.
         */

    }, {
        key: 'removeTokens',
        value: function removeTokens() {
            localStorage.removeItem('access_token');
            localStorage.removeItem('expires_in');
            localStorage.removeItem('refresh_token');
            localStorage.removeItem('token_type');
        }
    }]);

    return TokenHelper;
}();

exports.default = TokenHelper;