/**
 * Класс для работы с токенами.
 */
class TokenHelper {
    /**
     * Установка токенов.
     *
     * @param {string} access_token
     * @param {int} expires_in
     * @param token_type
     * @param {string} refresh_token
     */
    setToken(access_token, expires_in, token_type = 'Bearer', refresh_token = undefined) {

        const results = [
            this.setAccessToken(access_token),
            this.setTokenExpire(expires_in),
            this.setTokenType(token_type),
            this.setRefreshToken(refresh_token)
        ];

        const errors = [];

        results.forEach(result => {
            if (result instanceof Error) {
                console.warn(result);
                return errors.push(result);
            }
        });

        if (errors.length > 0) {
            return errors[0];
        }

        return errors.length > 0 ? errors[0] : true;
    }

    setAccessToken(access_token) {
        if (typeof access_token !== 'string' || access_token.length < 1) {
            return new Error('Переданное значение должно быть строкой и не быть пустой!');
        } else {
            localStorage.setItem('access_token', access_token);
            return true;
        }
    }

    setTokenType(token_type) {
        if (typeof token_type !== 'string' || token_type.length < 1) {
            return new Error('Переданное значение должно быть строкой и не быть пустой!');
        } else {
            localStorage.setItem('token_type', token_type);
            return true;
        }
    }

    setTokenExpire(expire_time) {
        if (typeof expire_time !== 'number') {
            return new Error('Переданное значение должно быть числом!');
        } else {
            localStorage.setItem('expires_in', expire_time + +new Date());
            return true;
        }
    }

    setRefreshToken(refresh_token) {
        if (typeof refresh_token !== 'undefined' && (typeof refresh_token !== 'string' || refresh_token.length < 1)) {
            return new Error('Переданное значение может быть не обязательным или должно быть строкой и не быть пустой!');
        } else {
            localStorage.setItem('refresh_token', refresh_token);
            return true;
        }
    }

    /**
     * Проверить авторизованность (наличие установленного токена и время его жизни).
     */
    isAuthenticated() {
        return !this.tokenWasExpired() && !!this.getToken()
    }

    /**
     * Получить токен доступа.
     */
    getToken() {
        return localStorage.getItem('access_token')
    }

    /**
     * Проверить, истекло ли время жизни токена.
     */
    tokenWasExpired() {
        const expires_in = localStorage.getItem('expires_in');

        return !expires_in ? false : new Date() >= expires_in;
    }

    /**
     * Удалить токены из хранилища.
     */
    removeTokens() {
        localStorage.removeItem('access_token');
        localStorage.removeItem('expires_in');
        localStorage.removeItem('refresh_token');
        localStorage.removeItem('token_type');
    }
}

export default TokenHelper;